<?php

namespace App\Http\Controllers\Back\Dashboard\Catalogos;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Library\URI;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use App\Http\Requests\Back\Dashboard\Catalogos\Puertas\CreateRequest;
use App\Http\Requests\Back\Dashboard\Catalogos\Puertas\EditRequest;
use Illuminate\Database\QueryException;
use App\Models\CatPuertas;
use App\Models\Puertas;
use App\Models\ProductosGaleria;

class PuertasController extends Controller {
    public function index(){
        //DB::connection()->enableQueryLog();

        $puertas = Puertas::select("tb_puertas.id", "cat_puertas.vc_puerta", "tb_puertas.vc_modelo", "tb_puertas.f_precio", "tb_productos_galleria.vc_imagen")
        ->leftJoin('tb_productos_galleria', 'tb_puertas.id', '=', 'tb_productos_galleria.i_producto')
        ->join('cat_puertas', 'cat_puertas.id', '=', 'tb_puertas.i_cat')
        ->where("tb_productos_galleria.i_tipo", "1")
        ->where("tb_productos_galleria.i_catalogo", "1")
        ->whereNull("tb_productos_galleria.deleted_at")
        ->orWhereNull("tb_productos_galleria.i_tipo")
        ->groupBy("tb_puertas.id")
        ->get();
        //dd( DB::getQueryLog() );
        return view('back.dashboard.catalogos.puertas.index', ["puertas" => $puertas, "permitions" => URI::checkPermitions()]);
    }

    public function create(){
        $catPuertas = CatPuertas::get();
        return view('back.dashboard.catalogos.puertas.create', ["catPuertas" => $catPuertas, "permitions" => URI::checkPermitions()]);
    }

    public function store(CreateRequest $r){
        $response = array( 'status' => false, 'message' => "No hemos podido almacenar los datos, intentalo nuevamente." );

        try {
            $puertas = new Puertas;
            $puertas->i_cat = $r->puerta;
            $puertas->vc_modelo = $r->modelo;
            $puertas->vc_url = $r->url;
            $puertas->vc_codigo_articulo = $r->codigoProducto;
            $puertas->b_mas_vendido = ( $r->masVendido == null ) ? 0 : 1;
            $puertas->tx_descripcion = ( $r->desc !== null ) ? $r->desc : '';
            $puertas->tx_caracteristicas = ( $r->cara !== null ) ? $r->cara : '';
            $puertas->vc_ficha = "";
            $puertas->vc_configuracion = $r->configuracion;
            $puertas->b_premium = ( $r->premium == null ) ? 0 : 1;
            $puertas->f_precio = number_format($r->precio, 2, '.', '');
            $puertas->i_descuento = ( $r->descuento == "" ) ? 0 : $r->descuento;
            $puertas->vc_apertura = $r->apertura;
            $puertas->f_alto = number_format($r->alto, 2, '.', '');
            $puertas->f_ancho = number_format($r->ancho, 2, '.', '');
            $puertas->f_peso = number_format($r->peso, 2, '.', '');
            $puertas->b_status = ( $r->status == null ) ? 0 : 1;

            //Files
            if( $r->has("ficha") ) {
                $fName = $r->file('ficha');
                $fileName = MD5($r->file('ficha') . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                $r->file('ficha')->move("pdf/ficha_tecnica", $fileName);
                $puertas->vc_ficha = "/pdf/ficha_tecnica/" . $fileName;
            }

            if ( $puertas->save() ) {
                //Files
                if( $r->has("imagen") ) {
                    $arrayGaleria = $r->file('imagen');
                    foreach ( $arrayGaleria as $key => $item ) {
                        //dd( $puertas->id, $r->tipo[$key], $r->post() );
                        $galeria = new ProductosGaleria;
                        $galeria->i_producto = $puertas->id;
                        $galeria->i_catalogo = 1;
                        $galeria->i_tipo = $r->tipo[$key];
                        $galeria->vc_titulo = $r->tituloImagen[$key];
                        $galeria->tx_descripcion = $r->descImagen[$key];
                        $galeria->b_status = 1;

                        $fName = $item;
                        $fileName = MD5($item . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                        $item->move("images/catalogos/puertas", $fileName);
                        $galeria->vc_imagen = "/images/catalogos/puertas/" . $fileName;

                        $galeria->save();
                    }
                }
            }

            $response = array( 
                'status' => true, 
                'message' => "Los datos se han almacenado correctamente.", 
                'url' => route('puertas.index') 
            );
        } catch ( QueryException $e ) {
            if ( strpos($e->errorInfo[2], "i_tipo") ) {
                $error = "El campo 'Tipo' en galería es obligatorio";
            } else if ( $e->errorInfo[1] == "1062" ) {
                $error = "El modelo ingresado está duplicado";
            } else {
                $error = $e->getMessage();
            }
            $response = array( 'status' => false, 'message' => $error );
        }
        return response()->json($response);
    }

    public function show($id){
        //
    }

    public function edit($id){
        $puertas = Puertas::where("id", base64_decode($id))->get();
        $catPuertas = CatPuertas::get();
        $catGaleria = ProductosGaleria::where("i_producto", $puertas[0]->id)->where("i_catalogo",1)->get();
        return view('back.dashboard.catalogos.puertas.edit', ["puertas" => $puertas, "catPuertas" => $catPuertas, "catGaleria" => $catGaleria, "permitions" => URI::checkPermitions()]);
    }

    public function update(EditRequest $r, $id){
        $response = array( 'status' => false, 'message' => "No hemos podido almacenar los datos, intentalo nuevamente." );    

        try {
            $puertas = Puertas::where("id", base64_decode($id))->get();
            $galeria = Puertas::where("id", base64_decode($id))->get();

            $puertasUpdate = Puertas::where("id", base64_decode($id))->update([
                "i_cat" => $r->puerta,
                "vc_modelo" => $r->modelo,
                "vc_url" => $r->url,
                "tx_descripcion" => ( $r->desc !== null ) ? $r->desc : '',
                "tx_caracteristicas" => ( $r->cara !== null ) ? $r->cara : '',
                "vc_codigo_articulo" => $r->codigoProducto,
                "b_mas_vendido" => ( $r->masVendido == null ) ? 0 : 1,
                "vc_configuracion" => $r->configuracion,
                "b_premium" => ( $r->premium == null ) ? 0 : 1,
                "f_precio" => number_format($r->precio, 2, '.', ''),
                "i_descuento" => ( $r->descuento == "" ) ? 0 : $r->descuento,
                "vc_apertura" => $r->apertura,
                "f_alto" => number_format($r->alto, 2, '.', ''),
                "f_ancho" => number_format($r->ancho, 2, '.', ''),
                "f_peso" => number_format($r->peso, 2, '.', ''),
                "b_status" => ( $r->status == null ) ? 0 : 1
            ]);

            //Ficha Técnica
            if( $r->has("ficha") ) {
                $path = ltrim($puertas[0]->vc_ficha, '/');
                if ( File::exists($path) ) {
                    unlink( $path );
                }

                $fName = $r->file('ficha');
                $fileName = MD5($r->file('ficha') . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                $r->file('ficha')->move("pdf/ficha_tecnica", $fileName);
                $puertasUpdate = Puertas::where("id", base64_decode($id))->update([ "vc_ficha" => "/pdf/ficha_tecnica/" . $fileName ]);
            }

            //GaleriaToUpdate
            if ( $r->idImagenToUpdate != null ){
                foreach( $r->idImagenToUpdate as $key => $item ) {
                    $galeriaDestroy = ProductosGaleria::where("id", $item)->get();

                    if( isset($r->file('imagenToUpdate')[$key]) ) {
                        $path = ltrim($galeriaDestroy[0]->vc_imagen, '/');
                        if ( File::exists($path) ) {
                            unlink( $path );
                        }

                        $fName = $r->file('imagenToUpdate')[$key];
                        $fileName = MD5($r->file('imagenToUpdate')[$key] . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                        $r->file('imagenToUpdate')[$key]->move("images/catalogos/puertas", $fileName);
                        $updateGaleria = ProductosGaleria::where("id", $item)->update([ "vc_imagen" => "/images/catalogos/puertas/" . $fileName ]);

                        ProductosGaleria::where("id", $item)
                        ->update([
                            "i_tipo" => $r->tipoToUpdate[$key],
                            "vc_titulo" => $r->tituloImagenToUpdate[$key],
                            "tx_descripcion" => $r->descImagenToUpdate[$key]
                        ]);
                    } else {
                        ProductosGaleria::where("id", $item)
                        ->update([
                            "i_tipo" => $r->tipoToUpdate[$key],
                            "vc_titulo" => $r->tituloImagenToUpdate[$key],
                            "tx_descripcion" => $r->descImagenToUpdate[$key]
                        ]);
                    }
                }
            }

            //Galeria
            if( $r->has("imagen") ) {
                $arrayGaleria = $r->file('imagen');
                foreach ( $arrayGaleria as $key => $item ) {
                    $galeria = new ProductosGaleria;
                    $galeria->i_producto = base64_decode($id);
                    $galeria->i_catalogo = 1;
                    $galeria->i_tipo = $r->tipo[$key];
                    $galeria->vc_titulo = $r->tituloImagen[$key];
                    $galeria->tx_descripcion = $r->descImagen[$key];
                    $galeria->b_status = 1;

                    $fName = $item;
                    $fileName = MD5($item . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                    $item->move("images/catalogos/puertas", $fileName);
                    $galeria->vc_imagen = "/images/catalogos/puertas/" . $fileName;

                    $galeria->save();
                }
            }

            $response = array( 
                'status' => true, 
                'message' => "Los datos se han almacenado correctamente.", 
                'url' => route('puertas.index') 
            );
        } catch ( QueryException $e ) {
            if ( strpos($e->errorInfo[2], "i_tipo") ) {
                $error = "El campo 'Tipo' en galería es obligatorio";
            } else if ( $e->errorInfo[1] == "1062" ) {
                $error = "El modelo ingresado está duplicado";
            } else {
                $error = $e->getMessage();
            }
            $response = array( 'status' => false, 'message' => $error );
        }

        return response()->json($response);
    }

    public function destroy($id){
        $response = array( 'status' => false, 'message' => "No hemos podido almacenar los datos, intentalo nuevamente." );

        try {
            $puertas = Puertas::find(base64_decode($id));
            $galeria = ProductosGaleria::where("i_producto", $puertas->id)->where("i_catalogo", 1)->get();
            if( $puertas != null ) {
                if( $puertas->delete() ) {
                    if ( count($galeria) > 0 ){
                        foreach( $galeria as $item ) {
                            $path = ltrim($item->vc_imagen, '/');
                            if ( File::exists($path) ) {
                                unlink( $path );
                            }
                        }
                    }

                    $response = [
                        'message' => 'Se ha eliminado el registro correctamente.',
                        'status' => true,
                        'url' => route('puertas.index') 
                    ];
                }
            } else {
                $response = [
                    'message' => 'No hemos podido eliminar el registro, intentalo nuevamente.',
                    'status' => false
                ];
            }
        } catch ( QueryException $e ) {
            $response = array( 'status' => false, 'message' => $e->getMessage() );
        }

        return response()->json($response);
    }
}
