<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

use App\Http\Controllers\Api\Puertas\PuertasController;
use App\Http\Controllers\Api\Productos\ProductosController;
use App\Http\Controllers\Api\Conekta\PaymentController;
use App\Http\Controllers\Api\Conekta\AddressController;
use App\Http\Controllers\Api\Conekta\TresGuerrasController;
use App\Http\Controllers\Api\Galerias\BannersHomeController;
use App\Http\Controllers\Api\Home\ResenasController;
use App\Http\Controllers\Api\PuertasMedida\Elementos\PuertasMedidaController;
use App\Http\Controllers\Api\Send\ContactoController;
/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::prefix("home")->group(function() {
    Route::get(
        'get-resenas', 
        [
            ResenasController::class, 
            "getResenas"
        ]
    );
});

Route::prefix("galerias")->group(function() {
    Route::get(
        'get-banners-home', 
        [
            BannersHomeController::class, 
            "getBannersHome"
        ]
    );
});

Route::prefix('productos')->group(function () {
    Route::post(
        'deleteImageFromGallery', 
        [
            ProductosController::class, 
            "deleteImageFromGallery"
        ]
    );
});

Route::prefix('puertas')->group(function () {
    Route::get(
        'get-carousel', 
        [
            PuertasController::class, 
            "getCarousel"
        ]
    );
});

/* Catalogos */
    Route::prefix('catalogos/')->group(function() {
        /* Puertas */
        Route::get("/puertas", [PuertasController::class, "index"]);
        Route::get("/puertas/{id}", [PuertasController::class, "show"]);
        Route::get("/puerta/{url}", [PuertasController::class, "showUrl"]);

        /* Productos */
        Route::get("/productos", [ProductosController::class, "index"]);
        Route::get("/productos/{url}", [ProductosController::class, "showUrl"]);
    });

    Route::prefix('conekta')->group(function() {
        /* simple pay */
        Route::post("simple-pay", [PaymentController::class, "simplePay"]);
        /* Direcciones */
        Route::get("get-all", [AddressController::class, "getAll"]);
        Route::get("get-states", [AddressController::class, "getStates"]);
        Route::get("get-cities", [AddressController::class, "getCities"]);
        Route::get("get-suburb", [AddressController::class, "getSuburb"]);
        /* Estimación */
        Route::post("get-estimation", [TresGuerrasController::class, "getEstimation"]);

    });

/* Puertas a medida */
    Route::prefix('puertas-a-medida/')->group(function() {
        Route::prefix('elementos/')->group(function() {
            Route::get("/base", [PuertasMedidaController::class, "base"]);
            Route::get("/getAll", [PuertasMedidaController::class, "getAll"]);
        });

        Route::prefix('pesos/')->group(function() {
            Route::get("/list-weight", [PuertasMedidaController::class, "listWeight"]);
        });
        
        Route::prefix('elementos/')->group(function() {
            Route::get("/get-textura-exterior/{id}", [PuertasMedidaController::class, "getTexturaExterior"]);
            Route::get("/get-textura-interior/{id}", [PuertasMedidaController::class, "getTexturaInterior"]);
            Route::get("/get-armazones", [PuertasMedidaController::class, "getArmazones"]);
            Route::get("/get-disenos", [PuertasMedidaController::class, "getDisenos"]);
            Route::get("/get-cristal", [PuertasMedidaController::class, "getCristal"]);
            Route::get("/get-celosia", [PuertasMedidaController::class, "getCelosia"]);
            Route::get("/get-maneral", [PuertasMedidaController::class, "getManeral"]);
            Route::get("/get-manija", [PuertasMedidaController::class, "getManija"]);
            Route::get("/get-fijos", [PuertasMedidaController::class, "getFijos"]);
        });
    });

/* Correos */
    Route::prefix('send')->group(function() {
        Route::post("contacto", [ContactoController::class, "send"]);
    });